@@ -3,7 +3,7 @@ package RiveScript;
 use strict;
 use warnings;
 
-our $VERSION = '1.24'; # Version of the Perl RiveScript interpreter.
+our $VERSION = '1.26'; # Version of the Perl RiveScript interpreter.
 our $SUPPORT = '2.0';  # Which RS standard we support.
 our $basedir = (__FILE__ =~ /^(.+?)\.pm$/i ? $1 : '.');
 
@@ -3179,6 +3179,10 @@ L<http://www.rivescript.com/> - The official homepage of RiveScript.
 
 =head1 CHANGES
 
+  1.26  May 29 2012
+  - Added EXE_FILES to Makefile.PL so the rivescript utility installs
+    correctly.
+
   1.24  May 15 2012
   - Fixed: having a single-line, multiline comment, e.g. /* ... */
   - Fixed: you can use <input> and <reply> in triggers now, instead of only
